package com.bigdata.wxappserver.service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.bigdata.wxappserver.entity.Order;
import com.bigdata.wxappserver.enums.OrderStatusEnum;
import com.bigdata.wxappserver.mapper.OrderMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * Created with IntelliJ IDEA.
 *
 * @Author: Cool
 * @Date: 2024/08/28/20:28
 * @Description:
 */
@Service
public class OrderService extends ServiceImpl<OrderMapper, Order> {

    @Transactional(rollbackFor = Exception.class)
    public JSONObject addOrUpdate(JSONObject jsonObject) {
        Order order = jsonObject.toJavaObject(Order.class);
        if (order==null){
            return new JSONObject().fluentPut("success",false).fluentPut("message","参数错误");
        }
        // TODO 判空
        boolean success = saveOrUpdate(order);
        return new JSONObject().fluentPut("message","success").fluentPut("success",success);
    }

    public JSONObject list(JSONObject jsonObject){
        String userId = jsonObject.getString("userId");
        Integer currentPage = jsonObject.getInteger("currentPage");
        Integer pageSize = jsonObject.getInteger("pageSize");
        IPage<Order> page=new Page<>(currentPage,pageSize);
        LambdaQueryWrapper<Order> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(userId!=null,Order::getUserId,userId);
        IPage<Order> orderIPage = page(page, wrapper);
        dealList(orderIPage.getRecords());
        JSONObject returnData=new JSONObject();
        returnData.fluentPut("data",orderIPage.getRecords())
                .fluentPut("total",orderIPage.getTotal())
                .fluentPut("current",orderIPage.getCurrent());
        return returnData;
    }

    private void dealList(List<Order> records) {
        if(CollectionUtils.isEmpty(records)){
            return;
        }
        for (Order record : records) {
            record.setStatusDescription(OrderStatusEnum.describe(record.getStatus()));
        }
    }


}
